@@ -443,4 +443,14 @@ if(!isGeneric("SymmCenter")){
 }
 if(!isGeneric("Symmetry")){
     setGeneric("Symmetry", function(object) standardGeneric("Symmetry"))
-}
\ No newline at end of file
+}
+if(!isGeneric("distribution")){
+    setGeneric("distribution", function(object) standardGeneric("distribution"))
+}
+if(!isGeneric("samplesize")){
+    setGeneric("samplesize", function(object, ...) standardGeneric("samplesize"))
+}
+if(!isGeneric("samplesize<-")){
+    setGeneric("samplesize<-",
+        function(object, value) standardGeneric("samplesize<-"))
+}
